"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cryptography = __importStar(require("@liskhq/lisk-cryptography"));
const constants_1 = require("./constants");
const utils_1 = require("./utils");
const createAsset = (data) => {
    if (data && data.length > 0) {
        return { data };
    }
    return {};
};
const validateInputs = ({ amount, recipientId, recipientPublicKey, data, }) => {
    if (!utils_1.validateTransferAmount(amount)) {
        throw new Error('Amount must be a valid number in string format.');
    }
    if (!recipientId && !recipientPublicKey) {
        throw new Error('Either recipientId or recipientPublicKey must be provided.');
    }
    if (typeof recipientId !== 'undefined') {
        utils_1.validateAddress(recipientId);
    }
    if (typeof recipientPublicKey !== 'undefined') {
        utils_1.validatePublicKey(recipientPublicKey);
    }
    if (recipientId &&
        recipientPublicKey &&
        recipientId !== cryptography.getAddressFromPublicKey(recipientPublicKey)) {
        throw new Error('recipientId does not match recipientPublicKey.');
    }
    if (data && data.length > 0) {
        if (typeof data !== 'string') {
            throw new Error('Invalid encoding in transaction data. Data must be utf-8 encoded string.');
        }
        if (data.length > constants_1.BYTESIZES.DATA) {
            throw new Error('Transaction data field cannot exceed 64 bytes.');
        }
    }
};
exports.transfer = (inputs) => {
    validateInputs(inputs);
    const { data, amount, recipientPublicKey, passphrase, secondPassphrase, timeOffset, } = inputs;
    const recipientIdFromPublicKey = recipientPublicKey
        ? cryptography.getAddressFromPublicKey(recipientPublicKey)
        : undefined;
    const recipientId = inputs.recipientId
        ? inputs.recipientId
        : recipientIdFromPublicKey;
    const transaction = {
        type: 0,
        amount: amount.toString(),
        fee: constants_1.TRANSFER_FEE.toString(),
        recipientId,
        recipientPublicKey,
        asset: createAsset(data),
    };
    return utils_1.prepareTransaction(transaction, passphrase, secondPassphrase, timeOffset);
};
//# sourceMappingURL=0_transfer.js.map