"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cryptography = __importStar(require("@liskhq/lisk-cryptography"));
const constants_1 = require("./constants");
const utils_1 = require("./utils");
const validateInputs = ({ votes = [], unvotes = [] }) => {
    if (!Array.isArray(votes)) {
        throw new Error('Please provide a valid votes value. Expected an array if present.');
    }
    if (!Array.isArray(unvotes)) {
        throw new Error('Please provide a valid unvotes value. Expected an array if present.');
    }
    utils_1.validatePublicKeys([...votes, ...unvotes]);
};
exports.castVotes = (inputs) => {
    validateInputs(inputs);
    const { passphrase, secondPassphrase, timeOffset, votes = [], unvotes = [], } = inputs;
    const recipientId = passphrase
        ? cryptography.getAddressAndPublicKeyFromPassphrase(passphrase).address
        : '';
    const plusPrependedVotes = utils_1.prependPlusToPublicKeys(votes);
    const minusPrependedUnvotes = utils_1.prependMinusToPublicKeys(unvotes);
    const allVotes = [
        ...plusPrependedVotes,
        ...minusPrependedUnvotes,
    ];
    const transaction = {
        type: 3,
        fee: constants_1.VOTE_FEE.toString(),
        recipientId,
        asset: {
            votes: allVotes,
        },
    };
    return utils_1.prepareTransaction(transaction, passphrase, secondPassphrase, timeOffset);
};
//# sourceMappingURL=3_cast_votes.js.map