"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./constants");
const utils_1 = require("./utils");
const validateInputs = ({ options }) => {
    if (typeof options !== 'object') {
        throw new Error('Options must be an object.');
    }
    const { category, name, type, link, description, tags, icon } = options;
    if (!utils_1.isValidInteger(category)) {
        throw new Error('Dapp category must be an integer.');
    }
    if (typeof name !== 'string') {
        throw new Error('Dapp name must be a string.');
    }
    if (!utils_1.isValidInteger(type)) {
        throw new Error('Dapp type must be an integer.');
    }
    if (typeof link !== 'string') {
        throw new Error('Dapp link must be a string.');
    }
    if (typeof description !== 'undefined' && typeof description !== 'string') {
        throw new Error('Dapp description must be a string if provided.');
    }
    if (typeof tags !== 'undefined' && typeof tags !== 'string') {
        throw new Error('Dapp tags must be a string if provided.');
    }
    if (typeof icon !== 'undefined' && typeof icon !== 'string') {
        throw new Error('Dapp icon must be a string if provided.');
    }
};
exports.createDapp = (inputs) => {
    validateInputs(inputs);
    const { passphrase, secondPassphrase, timeOffset, options } = inputs;
    const transaction = {
        type: 5,
        fee: constants_1.DAPP_FEE.toString(),
        asset: {
            dapp: {
                category: options.category,
                name: options.name,
                description: options.description,
                tags: options.tags,
                type: options.type,
                link: options.link,
                icon: options.icon,
            },
        },
    };
    return utils_1.prepareTransaction(transaction, passphrase, secondPassphrase, timeOffset);
};
//# sourceMappingURL=5_create_dapp.js.map