export interface BaseTransaction {
    readonly amount: string;
    readonly asset: TransactionAsset;
    readonly fee: string;
    readonly id?: string;
    readonly recipientId: string | null;
    readonly recipientPublicKey?: string | null;
    readonly requesterPublicKey?: string;
    readonly senderId?: string;
    readonly senderPublicKey: string;
    readonly signature?: string;
    readonly signatures?: ReadonlyArray<string>;
    readonly signSignature?: string;
    readonly timestamp: number;
    readonly type: number;
}
declare type Partial<T> = {
    [P in keyof T]?: T[P];
};
export declare type PartialTransaction = Partial<BaseTransaction>;
export declare type TransactionAsset = TransferAsset | SecondSignatureAsset | DelegateAsset | VoteAsset | MultiSignatureAsset | DappAsset | InTransferAsset | OutTransferAsset;
export interface TransferTransaction extends BaseTransaction {
    readonly asset: TransferAsset;
}
export interface TransferAsset {
    readonly data?: string;
}
export interface SecondSignatureTransaction extends BaseTransaction {
    readonly asset: SecondSignatureAsset;
}
export interface SecondSignatureAsset {
    readonly signature: {
        readonly publicKey: string;
    };
}
export interface DelegateTransaction extends BaseTransaction {
    readonly asset: DelegateAsset;
}
export interface DelegateAsset {
    readonly delegate: {
        readonly username: string;
    };
}
export interface VoteTransaction extends BaseTransaction {
    readonly asset: VoteAsset;
}
export interface VoteAsset {
    readonly votes: ReadonlyArray<string>;
}
export interface MultiSignatureTransaction extends BaseTransaction {
    readonly asset: MultiSignatureAsset;
}
export interface MultiSignatureAsset {
    readonly multisignature: {
        readonly keysgroup: ReadonlyArray<string>;
        readonly lifetime: number;
        readonly min: number;
    };
}
export interface DappTransaction extends BaseTransaction {
    readonly asset: DappAsset;
}
export interface DappAsset {
    readonly dapp: {
        readonly category: number;
        readonly description?: string;
        readonly icon?: string;
        readonly link: string;
        readonly name: string;
        readonly tags?: string;
        readonly type: number;
    };
}
export interface InTransferTransaction extends BaseTransaction {
    readonly asset: InTransferAsset;
}
export interface InTransferAsset {
    readonly inTransfer: {
        readonly dappId: string;
    };
}
export interface OutTransferTransaction extends BaseTransaction {
    readonly asset: OutTransferAsset;
}
export interface OutTransferAsset {
    readonly outTransfer: {
        readonly dappId: string;
        readonly transactionId: string;
    };
}
export {};
