'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getFirstLineFromString = undefined;

var _utils = require('./utils');

const getFirstLineFromString = exports.getFirstLineFromString = multilineString => typeof multilineString === 'string' ? multilineString.split(/[\r\n]+/)[0] : null; /*
                                                                                                                                                                      * LiskHQ/lisk-commander
                                                                                                                                                                      * Copyright © 2017–2018 Lisk Foundation
                                                                                                                                                                      *
                                                                                                                                                                      * See the LICENSE file at the top-level directory of this distribution
                                                                                                                                                                      * for licensing information.
                                                                                                                                                                      *
                                                                                                                                                                      * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                                                                                                                                                      * no part of this software, including this file, may be copied, modified,
                                                                                                                                                                      * propagated, or distributed except according to the terms contained in the
                                                                                                                                                                      * LICENSE file.
                                                                                                                                                                      *
                                                                                                                                                                      * Removal or modification of this copyright notice is prohibited.
                                                                                                                                                                      *
                                                                                                                                                                      */


const getInputsFromSources = async ({
	passphrase: passphraseInput,
	secondPassphrase: secondPassphraseInput,
	password: passwordInput,
	data: dataInput
}) => {
	const [passphraseIsRequired, secondPassphraseIsRequired, passwordIsRequired, dataIsRequired] = [passphraseInput, secondPassphraseInput, passwordInput, dataInput].map(input => !!input && input.source === 'stdin');

	const stdIn = await (0, _utils.getStdIn)({
		passphraseIsRequired,
		secondPassphraseIsRequired,
		passwordIsRequired,
		dataIsRequired
	});

	const passphrase = typeof stdIn.passphrase !== 'string' && passphraseInput ? await (0, _utils.getPassphrase)(passphraseInput.source, {
		shouldRepeat: passphraseInput.repeatPrompt
	}) : stdIn.passphrase || null;

	const secondPassphrase = typeof stdIn.secondPassphrase !== 'string' && secondPassphraseInput ? await (0, _utils.getPassphrase)(secondPassphraseInput.source, {
		displayName: 'your second secret passphrase',
		shouldRepeat: secondPassphraseInput.repeatPrompt
	}) : stdIn.secondPassphrase || null;

	const password = typeof stdIn.password !== 'string' && passwordInput ? await (0, _utils.getPassphrase)(passwordInput.source, {
		displayName: 'your password',
		shouldRepeat: passwordInput.repeatPrompt
	}) : stdIn.password || null;

	const data = typeof stdIn.data !== 'string' && dataInput ? await (0, _utils.getData)(dataInput.source) : stdIn.data || null;

	return {
		passphrase,
		secondPassphrase,
		password,
		data
	};
};

exports.default = getInputsFromSources;